aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/cmd/compile/internal/types2/lookup.go10
-rw-r--r--src/go/types/lookup.go10
2 files changed, 10 insertions, 10 deletions
diff --git a/src/cmd/compile/internal/types2/lookup.go b/src/cmd/compile/internal/types2/lookup.go
index b8d120f154..8f87dc0961 100644
--- a/src/cmd/compile/internal/types2/lookup.go
+++ b/src/cmd/compile/internal/types2/lookup.go
@@ -67,13 +67,13 @@ func lookupFieldOrMethod(T Type, addressable bool, pkg *Package, name string, fo
obj, index, indirect = lookupFieldOrMethodImpl(T, addressable, pkg, name, foldCase)
// If we didn't find anything and if we have a type parameter with a core type,
// see if there is a matching field (but not a method, those need to be declared
// explicitly in the constraint). If the constraint is a named pointer type (see
// above), we are ok here because only fields are accepted as results.
const enableTParamFieldLookup = false // see go.dev/issue/51576
if enableTParamFieldLookup && obj == nil && isTypeParam(T) {
- if t := coreType(T); t != nil {
+ if t := sharedUnder(nil, T, nil); t != nil {
obj, index, indirect = lookupFieldOrMethodImpl(t, addressable, pkg, name, foldCase)
if _, ok := obj.(*Var); !ok {
obj, index, indirect = nil, nil, false // accept fields (variables) only
@@ -67,13 +67,13 @@ func lookupFieldOrMethod(T Type, addressable bool, pkg *Package, name string, fo
obj, index, indirect = lookupFieldOrMethodImpl(T, addressable, pkg, name, foldCase)
- // If we didn't find anything and if we have a type parameter with a core type,
- // see if there is a matching field (but not a method, those need to be declared
- // explicitly in the constraint). If the constraint is a named pointer type (see
- // above), we are ok here because only fields are accepted as results.
+ // If we didn't find anything and if we have a type parameter with a shared underlying
+ // type, see if there is a matching field (but not a method, those need to be declared
+ // explicitly in the constraint). If the constraint is a named pointer type (see above),
+ // we are ok here because only fields are accepted as results.
const enableTParamFieldLookup = false // see go.dev/issue/51576
if enableTParamFieldLookup && obj == nil && isTypeParam(T) {
diff --git a/src/go/types/lookup.go b/src/go/types/lookup.go
index 6c95a9c8d7..cbf16ae7c8 100644
--- a/src/go/types/lookup.go
+++ b/src/go/types/lookup.go
@@ -70,13 +70,13 @@ func lookupFieldOrMethod(T Type, addressable bool, pkg *Package, name string, fo
obj, index, indirect = lookupFieldOrMethodImpl(T, addressable, pkg, name, foldCase)
// If we didn't find anything and if we have a type parameter with a core type,
// see if there is a matching field (but not a method, those need to be declared
// explicitly in the constraint). If the constraint is a named pointer type (see
// above), we are ok here because only fields are accepted as results.
const enableTParamFieldLookup = false // see go.dev/issue/51576
if enableTParamFieldLookup && obj == nil && isTypeParam(T) {
- if t := coreType(T); t != nil {
+ if t := sharedUnder(nil, T, nil); t != nil {
obj, index, indirect = lookupFieldOrMethodImpl(t, addressable, pkg, name, foldCase)
if _, ok := obj.(*Var); !ok {
obj, index, indirect = nil, nil, false // accept fields (variables) only
@@ -70,13 +70,13 @@ func lookupFieldOrMethod(T Type, addressable bool, pkg *Package, name string, fo
obj, index, indirect = lookupFieldOrMethodImpl(T, addressable, pkg, name, foldCase)
- // If we didn't find anything and if we have a type parameter with a core type,
- // see if there is a matching field (but not a method, those need to be declared
- // explicitly in the constraint). If the constraint is a named pointer type (see
- // above), we are ok here because only fields are accepted as results.
+ // If we didn't find anything and if we have a type parameter with a shared underlying
+ // type, see if there is a matching field (but not a method, those need to be declared
+ // explicitly in the constraint). If the constraint is a named pointer type (see above),
+ // we are ok here because only fields are accepted as results.
const enableTParamFieldLookup = false // see go.dev/issue/51576
if enableTParamFieldLookup && obj == nil && isTypeParam(T) {